/*
* File :        PCF8583.h
* objet :       Constantes pour utilitaires du compteur Geiger
* Auteur :      Pascal Chour
* cr le :     26/11/2015
* Copyright :   (C) Pascal Chour (2015)
*/

#ifndef __INCLUDE_GEIGERUTIL_H
#define __INCLUDE_GEIGERUTIL_H

#include <msp430x44x.h>
#include <inttypes.h>
#include "globales.h"

#define ADC_VREF_DELAY_MS (17) // dlai pour stabilisation ADC en ms

/* 
Cette fonction fait un dlai d'attente LOGICIEL  de x ms.
Elle fonctionne pur une frquence donne du processeur qui 
doit tre fixe  la compilation
*/

void delayMs(unsigned int delay);

/*
* Gestion des boutons poussoirs par polling
* Indique quels sont les poussoirs nouvellement appuys
* En entre : tat prcdent des poussoirs presss dans buttonPressed
* En sortie : tat courant dans buttonPressed et rsultat de la fonction
* 0 = pas de bouton appuy ou pas de changement depuis le dernier tat connu
*/
bool_t buttonHandler (unsigned int *buttonPressed);


/*
Cet utilitaire donne le niveau de la tension d'alimentation
du MSP430 et rend un rsultat utilisable pour afficher 
la jauge de la batterie sur l'afficheur 
0 : batterie vide (ou quasiment !)
1 : batterie faible
2 : batterie moyenne
3 : batterie charge

Cette procdure ne devrait pas tre appele trop souvent. Par
exemple, une fois toutes les minutes.
*/
unsigned int niveau_batterie(unsigned int *voltage);

/*
Emet la commande CM= avec la valeur de comptage passe en paramtre sur
l'UART0. L'UART doit avoir t pralablement initialise !
transmet 9999 si la valeur de comptage est suprieure  10000
*/
void EMET_CM(unsigned long v);

/*
transmet le contenu de s termin par 0x00 sur l'UART0
Pas de contrle de s ni de i
termine la transmission par LF/RC
*/

void UART0_writeln(char *s);

/*
 Traite la rception des commandes du host et renvoie les rponses
En entre, C, premier caractre reu (en gnral, la commande)
*/
void traite_commande(void);

/*
Rinitialise le buffer de rception sur UART0
*/
void UART0_initbuffer(void);

#endif // __INCLUDE_GEIGERUTIL_H

